@@ -1,7 +1,7 @@
 package Bencher::Scenario::PERLANCAR::require;
 
-our $DATE = '2016-01-21'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-23'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -75,7 +75,7 @@ Bencher::Scenario::PERLANCAR::require - Benchmark require() in a tight loop/subr
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::PERLANCAR::require (from Perl distribution Bencher-Scenarios-PERLANCAR), released on 2016-01-21.
+This document describes version 0.03 of Bencher::Scenario::PERLANCAR::require (from Perl distribution Bencher-Scenarios-PERLANCAR), released on 2016-03-23.
 
 =head1 SYNOPSIS
 
@@ -131,14 +131,14 @@ Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (
 
 Benchmark with default options (C<< bencher -m PERLANCAR::require >>):
 
- +--------------------+-------------+-----------+---------+---------+
- | participant        | rate (/s)   | time (ns) | errors  | samples |
- +--------------------+-------------+-----------+---------+---------+
- | require_in_sub     | 1.4e+07     | 73        | 2.5e-10 | 20      |
- | require_in_sub_pm  | 1.43e+07    | 70.1      | 5.2e-11 | 20      |
- | require_in_state   | 1.27825e+08 | 7.82322   | 0       | 20      |
- | baseline_empty_sub | 2e+09       | 0.6       | 5.5e-10 | 20      |
- +--------------------+-------------+-----------+---------+---------+
+ +--------------------+-----------+-----------+------------+---------+---------+
+ | participant        | rate (/s) | time (ns) | vs_slowest | errors  | samples |
+ +--------------------+-----------+-----------+------------+---------+---------+
+ | require_in_sub     | 1.28e+07  | 77.9      | 1          | 6.3e-11 | 26      |
+ | require_in_sub_pm  | 1.3e+07   | 74        | 1          | 9.3e-11 | 20      |
+ | require_in_state   | 1.2e+08   | 8.1       | 9.6        | 5.2e-11 | 20      |
+ | baseline_empty_sub | 4e+08     | 2         | 3e+01      | 2.1e-10 | 21      |
+ +--------------------+-----------+-----------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
